from setuptools import setup, find_packages

setup(
    name='motivationalqpy',
    version='0.1',
    packages=find_packages(),
    description='A minimal package for motivational quotes',
    author='darkbit',
    author_email='darkbit131@gmail.com',
    keywords=['motivation', 'quotes', 'inspiration'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
)
